@@ -6,25 +6,20 @@
 
 #include "loopbackdevicelink.h"
 
+#include "kdeconnectconfig.h"
 #include "loopbacklinkprovider.h"
 
-LoopbackDeviceLink::LoopbackDeviceLink(const QString& deviceId, LoopbackLinkProvider* provider)
-    : DeviceLink(deviceId, provider)
+LoopbackDeviceLink::LoopbackDeviceLink(LoopbackLinkProvider *parent)
+    : DeviceLink(KdeConnectConfig::instance().deviceId(), parent)
 {
-
 }
 
-QString LoopbackDeviceLink::name()
+bool LoopbackDeviceLink::sendPacket(NetworkPacket &input)
 {
-    return QStringLiteral("LoopbackLink");
-}
-
-bool LoopbackDeviceLink::sendPacket(NetworkPacket& input)
-{
-    NetworkPacket output((QString()));
+    NetworkPacket output;
     NetworkPacket::unserialize(input.serialize(), &output);
 
-    //LoopbackDeviceLink does not need deviceTransferInfo
+    // LoopbackDeviceLink does not need deviceTransferInfo
     if (input.hasPayload()) {
         bool b = input.payload()->open(QIODevice::ReadOnly);
         Q_ASSERT(b);
@@ -36,3 +31,9 @@ bool LoopbackDeviceLink::sendPacket(NetworkPacket& input)
     return true;
 }
 
+DeviceInfo LoopbackDeviceLink::deviceInfo() const
+{
+    return KdeConnectConfig::instance().deviceInfo();
+}
+
+#include "moc_loopbackdevicelink.cpp"
