@@ -26,9 +26,6 @@
 #include "networkpacket.h"
 #include "pluginloader.h"
 
-// In older Qt released, qAsConst isnt available
-#include "qtcompat_p.h"
-
 class Device::DevicePrivate
 {
 public:
@@ -65,7 +62,8 @@ Device::Device(QObject *parent, const QString &id)
     d = new Device::DevicePrivate(info);
 
     d->m_pairingHandler = new PairingHandler(this, PairState::Paired);
-    d->m_supportedPlugins = PluginLoader::instance()->getPluginList().toSet(); // Assume every plugin is supported until we get the capabilities
+    const auto supported = PluginLoader::instance()->getPluginList();
+    d->m_supportedPlugins = QSet(supported.begin(), supported.end()); // Assume every plugin is supported until we get the capabilities
 
     // Register in bus
     QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
@@ -82,7 +80,8 @@ Device::Device(QObject *parent, DeviceLink *dl)
     d = new Device::DevicePrivate(dl->deviceInfo());
 
     d->m_pairingHandler = new PairingHandler(this, PairState::NotPaired);
-    d->m_supportedPlugins = PluginLoader::instance()->getPluginList().toSet(); // Assume every plugin is supported until we get the capabilities
+    const auto supported = PluginLoader::instance()->getPluginList();
+    d->m_supportedPlugins = QSet(supported.begin(), supported.end()); // Assume every plugin is supported until we get the capabilities
 
     addLink(dl);
 
@@ -136,7 +135,7 @@ int Device::protocolVersion()
 
 QStringList Device::supportedPlugins() const
 {
-    return d->m_supportedPlugins.toList();
+    return QList(d->m_supportedPlugins.cbegin(), d->m_supportedPlugins.cend());
 }
 
 bool Device::hasPlugin(const QString &name) const
@@ -160,12 +159,11 @@ void Device::reloadPlugins()
 
         PluginLoader *loader = PluginLoader::instance();
 
-        for (const QString &pluginName : qAsConst(d->m_supportedPlugins)) {
+        for (const QString &pluginName : std::as_const(d->m_supportedPlugins)) {
             const KPluginMetaData service = loader->getPluginInfo(pluginName);
 
             const bool pluginEnabled = isPluginEnabled(pluginName);
-            const QSet<QString> incomingCapabilities =
-                KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
+            const QStringList incomingCapabilities = service.rawData().value(QStringLiteral("X-KdeConnect-SupportedPacketType")).toVariant().toStringList();
 
             if (pluginEnabled) {
                 KdeConnectPlugin *plugin = d->m_plugins.take(pluginName);
@@ -196,7 +194,7 @@ void Device::reloadPlugins()
 
     // Recreate dbus paths for all plugins (new and existing)
     QDBusConnection bus = QDBusConnection::sessionBus();
-    for (KdeConnectPlugin *plugin : qAsConst(d->m_plugins)) {
+    for (KdeConnectPlugin *plugin : std::as_const(d->m_plugins)) {
         const QString dbusPath = plugin->dbusPath();
         if (!dbusPath.isEmpty()) {
             bus.registerObject(dbusPath,
@@ -278,6 +276,10 @@ void Device::addLink(DeviceLink *link)
 
     d->m_deviceLinks.append(link);
 
+    std::sort(d->m_deviceLinks.begin(), d->m_deviceLinks.end(), [](DeviceLink *a, DeviceLink *b) {
+        return a->priority() > b->priority();
+    });
+
     connect(link, &QObject::destroyed, this, &Device::linkDestroyed);
     connect(link, &DeviceLink::receivedPacket, this, &Device::privateReceivedPacket);
 
@@ -296,10 +298,12 @@ void Device::addLink(DeviceLink *link)
 bool Device::updateDeviceInfo(const DeviceInfo &newDeviceInfo)
 {
     bool hasChanges = false;
-    if (d->m_deviceInfo.name != newDeviceInfo.name || d->m_deviceInfo.type != newDeviceInfo.type) {
+    if (d->m_deviceInfo.name != newDeviceInfo.name || d->m_deviceInfo.type != newDeviceInfo.type
+        || d->m_deviceInfo.protocolVersion != newDeviceInfo.protocolVersion) {
         hasChanges = true;
         d->m_deviceInfo.name = newDeviceInfo.name;
         d->m_deviceInfo.type = newDeviceInfo.type;
+        d->m_deviceInfo.protocolVersion = newDeviceInfo.protocolVersion;
         Q_EMIT typeChanged(d->m_deviceInfo.type.toString());
         Q_EMIT nameChanged(d->m_deviceInfo.name);
         if (isPaired()) {
@@ -318,7 +322,11 @@ bool Device::updateDeviceInfo(const DeviceInfo &newDeviceInfo)
 
     return hasChanges;
 }
-
+bool Device::hasInvalidCertificate()
+{
+    QDateTime now = QDateTime::currentDateTime();
+    return certificate().isNull() || certificate().effectiveDate() >= now || certificate().expiryDate() <= now;
+}
 void Device::linkDestroyed(QObject *o)
 {
     removeLink(static_cast<DeviceLink *>(o));
@@ -341,7 +349,7 @@ bool Device::sendPacket(NetworkPacket &np)
     Q_ASSERT(isPaired() || np.type() == PACKET_TYPE_PAIR);
 
     // Maybe we could block here any packet that is not an identity or a pairing packet to prevent sending non encrypted data
-    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
+    for (DeviceLink *dl : std::as_const(d->m_deviceLinks)) {
         if (dl->sendPacket(np))
             return true;
     }
@@ -394,7 +402,7 @@ bool Device::isPairRequestedByPeer() const
 
 QHostAddress Device::getLocalIpAddress() const
 {
-    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
+    for (DeviceLink *dl : std::as_const(d->m_deviceLinks)) {
         LanDeviceLink *ldl = dynamic_cast<LanDeviceLink *>(dl);
         if (ldl) {
             return ldl->hostAddress();
@@ -425,7 +433,7 @@ void Device::setPluginEnabled(const QString &pluginName, bool enabled)
         return;
     }
 
-    KConfigGroup pluginStates = KSharedConfig::openConfig(pluginsConfigFile())->group("Plugins");
+    KConfigGroup pluginStates = KSharedConfig::openConfig(pluginsConfigFile())->group(QStringLiteral("Plugins"));
 
     const QString enabledKey = pluginName + QStringLiteral("Enabled");
     pluginStates.writeEntry(enabledKey, enabled);
@@ -435,7 +443,7 @@ void Device::setPluginEnabled(const QString &pluginName, bool enabled)
 bool Device::isPluginEnabled(const QString &pluginName) const
 {
     const QString enabledKey = pluginName + QStringLiteral("Enabled");
-    KConfigGroup pluginStates = KSharedConfig::openConfig(pluginsConfigFile())->group("Plugins");
+    KConfigGroup pluginStates = KSharedConfig::openConfig(pluginsConfigFile())->group(QStringLiteral("Plugins"));
 
     return (pluginStates.hasKey(enabledKey) ? pluginStates.readEntry(enabledKey, false)
                                             : PluginLoader::instance()->getPluginInfo(pluginName).isEnabledByDefault());
@@ -448,16 +456,18 @@ QString Device::encryptionInfo() const
 
     QString localChecksum = QString::fromLatin1(KdeConnectConfig::instance().certificate().digest(digestAlgorithm).toHex());
     for (int i = 2; i < localChecksum.size(); i += 3) {
-        localChecksum.insert(i, QStringLiteral(":")); // Improve readability
+        localChecksum.insert(i, QLatin1Char(':')); // Improve readability
     }
     result += i18n("SHA256 fingerprint of your device certificate is: %1\n", localChecksum);
 
     QString remoteChecksum = QString::fromLatin1(certificate().digest(digestAlgorithm).toHex());
     for (int i = 2; i < remoteChecksum.size(); i += 3) {
-        remoteChecksum.insert(i, QStringLiteral(":")); // Improve readability
+        remoteChecksum.insert(i, QLatin1Char(':')); // Improve readability
     }
     result += i18n("SHA256 fingerprint of remote device certificate is: %1\n", remoteChecksum);
 
+    result += i18n("Protocol version: %1\n", d->m_deviceInfo.protocolVersion);
+
     return result;
 }
 
@@ -466,18 +476,9 @@ QSslCertificate Device::certificate() const
     return d->m_deviceInfo.certificate;
 }
 
-QByteArray Device::verificationKey() const
+QString Device::verificationKey() const
 {
-    auto a = KdeConnectConfig::instance().certificate().publicKey().toDer();
-    auto b = certificate().publicKey().toDer();
-    if (a < b) {
-        std::swap(a, b);
-    }
-
-    QCryptographicHash hash(QCryptographicHash::Sha256);
-    hash.addData(a);
-    hash.addData(b);
-    return hash.result().toHex();
+    return d->m_pairingHandler->verificationKey();
 }
 
 QString Device::pluginIconName(const QString &pluginName)
@@ -487,3 +488,5 @@ QString Device::pluginIconName(const QString &pluginName)
     }
     return QString();
 }
+
+#include "moc_device.cpp"
