@@ -9,20 +9,19 @@
 #include "kdeconnectcore_export.h"
 #include <QObject>
 
-class KDECONNECTCORE_EXPORT NotificationServerInfo
-    : public QObject
+class KDECONNECTCORE_EXPORT NotificationServerInfo : public QObject
 {
     Q_OBJECT
 
 public:
     enum Hint {
         X_KDE_DISPLAY_APPNAME = 1,
-        X_KDE_ORIGIN_NAME = 2
+        X_KDE_ORIGIN_NAME = 2,
     };
 
     Q_DECLARE_FLAGS(Hints, Hint)
 
-    static NotificationServerInfo& instance();
+    static NotificationServerInfo &instance();
 
     void init();
 
