@@ -23,12 +23,12 @@
 #include "interfaces/notificationsmodel.h"
 #include "openconfig.h"
 #include "pointerlocker.h"
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
+#include "pointerlockerwayland.h"
+#endif
 #include <pluginmodel.h>
 #include <remotecommandsmodel.h>
 #include <remotesinksmodel.h>
-#if WITH_WAYLAND
-#include "pointerlockerwayland.h"
-#endif
 
 QObject *createDBusResponse()
 {
@@ -71,6 +71,19 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
                                                             "RemoteKeyboardDbusInterface",
                                                             QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<DeviceDbusInterface>(uri, 1, 0, "DeviceDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<BatteryDbusInterface>(uri, 1, 0, "BatteryDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<ConnectivityReportDbusInterface>(uri,
+                                                                1,
+                                                                0,
+                                                                "ConnectivityReportDbusInterface",
+                                                                QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<SftpDbusInterface>(uri, 1, 0, "SftpDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<SmsDbusInterface>(uri, 1, 0, "SmsDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<VirtualmonitorDbusInterface>(uri,
+                                                            1,
+                                                            0,
+                                                            "VirtualmonitorDbusInterface",
+                                                            QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<RemoteCommandsDbusInterface>(uri,
                                                             1,
                                                             0,
@@ -82,14 +95,13 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
                                                                 "RemoteSystemVolumeInterface",
                                                                 QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<ShareDbusInterface>(uri, 1, 0, "ShareDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
-    qmlRegisterUncreatableType<PhotoDbusInterface>(uri, 1, 0, "PhotoDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<BigscreenDbusInterface>(uri, 1, 0, "BigscreenDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterSingletonType<DaemonDbusInterface>(uri, 1, 0, "DaemonDbusInterface", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return new DaemonDbusInterface;
     });
     qmlRegisterSingletonType<AbstractPointerLocker>("org.kde.kdeconnect", 1, 0, "PointerLocker", [](QQmlEngine *, QJSEngine *) -> QObject * {
         AbstractPointerLocker *ret;
-#if WITH_WAYLAND
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
         if (qGuiApp->platformName() == QLatin1String("wayland"))
             ret = new PointerLockerWayland;
         else
@@ -102,11 +114,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
         return new OpenConfig;
     });
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     qmlRegisterAnonymousType<QAbstractItemModel>(uri, 1);
-#else
-    qmlRegisterType<QAbstractItemModel>();
-#endif
 
     registerFactory<DeviceDbusInterface>(uri, "DeviceDbusInterfaceFactory");
     registerFactory<BatteryDbusInterface>(uri, "DeviceBatteryDbusInterfaceFactory");
@@ -121,7 +129,6 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
     registerFactory<SmsDbusInterface>(uri, "SmsDbusInterfaceFactory");
     registerFactory<RemoteCommandsDbusInterface>(uri, "RemoteCommandsDbusInterfaceFactory");
     registerFactory<ShareDbusInterface>(uri, "ShareDbusInterfaceFactory");
-    registerFactory<PhotoDbusInterface>(uri, "PhotoDbusInterfaceFactory");
     registerFactory<RemoteSystemVolumeDbusInterface>(uri, "RemoteSystemVolumeDbusInterfaceFactory");
     registerFactory<BigscreenDbusInterface>(uri, "BigscreenDbusInterfaceFactory");
     registerFactory<VirtualmonitorDbusInterface>(uri, "VirtualmonitorDbusInterfaceFactory");
@@ -135,3 +142,5 @@ void KdeConnectDeclarativePlugin::initializeEngine(QQmlEngine *engine, const cha
 
     engine->rootContext()->setContextProperty(QStringLiteral("DBusResponseWaiter"), DBusResponseWaiter::instance());
 }
+
+#include "moc_kdeconnectdeclarativeplugin.cpp"
