@@ -7,16 +7,14 @@
 #ifndef INDICATORHELPER_H
 #define INDICATORHELPER_H
 
-#include <QProcess>
-#include <QSplashScreen>
-
-#ifdef QSYSTRAY
+#ifdef Q_OS_WIN
 #include <QSystemTrayIcon>
 #else
 #include <KStatusNotifierItem>
 #endif
 
 #ifdef Q_OS_WIN
+#include <QProcess>
 #include <QUrl>
 namespace processes
 {
@@ -32,32 +30,23 @@ const QString kdeconnect_sms = QStringLiteral("kdeconnect-sms.exe");
 class IndicatorHelper
 {
 public:
-#ifdef Q_OS_WIN
-    IndicatorHelper(const QUrl &indicatorUrl);
-#else
     IndicatorHelper();
-#endif
     ~IndicatorHelper();
 
-    void preInit();
-    void postInit();
-
     void iconPathHook();
 
-    int daemonHook(QProcess &kdeconnectd);
+    int startDaemon();
 
-#ifdef QSYSTRAY
+#ifdef Q_OS_WIN
     void systrayIconHook(QSystemTrayIcon &systray);
 #else
     void systrayIconHook(KStatusNotifierItem &systray);
 #endif
 
 private:
-#ifdef Q_OS_MAC
-    QSplashScreen *m_splashScreen;
-#endif
-
 #ifdef Q_OS_WIN
+    QProcess kdeconnectd;
+
     /**
      * Terminate processes of KDE Connect like kdeconnectd.exe and dbus-daemon.exe
      *
