@@ -5,11 +5,17 @@
  */
 
 #include <QApplication>
+#include <QIcon>
 #include <QPointer>
 #include <QProcess>
+#include <QQuickStyle>
 #include <QThread>
 
-#ifdef QSYSTRAY
+#ifdef Q_OS_WIN
+#include <Windows.h>
+#endif
+
+#ifdef Q_OS_WIN
 #include <QSystemTrayIcon>
 #else
 #include <KStatusNotifierItem>
@@ -18,12 +24,14 @@
 #include <KAboutData>
 #include <KCMultiDialog>
 #include <KColorSchemeManager>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 
 #include "deviceindicator.h"
 #include "interfaces/dbusinterfaces.h"
 #include "interfaces/devicesmodel.h"
+#include "interfaces/devicessortproxymodel.h"
 #include "kdeconnect-version.h"
 
 #include <dbushelper.h>
@@ -32,11 +40,19 @@
 
 int main(int argc, char **argv)
 {
-    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#ifdef Q_OS_WIN
+    // If ran from a console, redirect the output there
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+#endif
 
     QApplication app(argc, argv);
+
+    IndicatorHelper helper;
+    helper.startDaemon();
+
     KAboutData about(QStringLiteral("kdeconnect-indicator"),
                      i18n("KDE Connect Indicator"),
                      QStringLiteral(KDECONNECT_VERSION_STRING),
@@ -46,22 +62,26 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(about);
 
 #ifdef Q_OS_WIN
-    KColorSchemeManager manager;
+    // Ensure we have a suitable color theme set for light/dark mode. KColorSchemeManager implicitly applies
+    // a suitable default theme.
+    KColorSchemeManager::instance();
+    // Force breeze style to ensure coloring works consistently in dark mode. Specifically tab colors have
+    // troubles on windows.
     QApplication::setStyle(QStringLiteral("breeze"));
-    IndicatorHelper helper(QUrl::fromLocalFile(qApp->applicationDirPath()));
+    // Force breeze icon theme to ensure we can correctly adapt icons to color changes WRT dark/light mode.
+    // Without this we may end up with hicolor and fail to support icon recoloring.
+    QIcon::setThemeName(QStringLiteral("breeze"));
 #else
-    IndicatorHelper helper;
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 #endif
 
-    helper.preInit();
-
-    // Run Daemon initialization step
-    // When run from macOS app bundle, D-Bus call should be later than kdeconnectd and D-Bus daemon
-    QProcess kdeconnectd;
-    if (helper.daemonHook(kdeconnectd)) {
-        return -1;
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
+    KCrash::initialize();
+
     KDBusService dbusService(KDBusService::Unique);
 
     // Trigger loading the KIconLoader plugin
@@ -69,19 +89,21 @@ int main(int argc, char **argv)
 
     DevicesModel model;
     model.setDisplayFilter(DevicesModel::Reachable | DevicesModel::Paired);
+    DevicesSortProxyModel proxyModel;
+    proxyModel.setSourceModel(&model);
     QMenu *menu = new QMenu;
 
     QPointer<KCMultiDialog> dialog;
 
     DaemonDbusInterface iface;
 
-    auto refreshMenu = [&iface, &model, &menu, &helper, &dialog]() {
+    auto refreshMenu = [&iface, &proxyModel, &menu, &dialog]() {
         menu->clear();
         auto configure = menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure..."));
         QObject::connect(configure, &QAction::triggered, configure, [&dialog]() {
             if (dialog == nullptr) {
                 dialog = new KCMultiDialog;
-                dialog->addModule(KPluginMetaData(QStringLiteral("kcm_kdeconnect")));
+                dialog->addModule(KPluginMetaData(QStringLiteral("plasma/kcms/systemsettings_qwidgets/kcm_kdeconnect")));
                 dialog->setAttribute(Qt::WA_DeleteOnClose);
                 dialog->show();
                 dialog->raise();
@@ -90,8 +112,12 @@ int main(int argc, char **argv)
                 dialog->activateWindow();
             }
         });
-        for (int i = 0, count = model.rowCount(); i < count; ++i) {
-            DeviceDbusInterface *device = model.getDevice(i);
+        for (int i = 0, count = proxyModel.rowCount(); i < count; ++i) {
+            QObject *deviceObject = proxyModel.data(proxyModel.index(i, 0), DevicesModel::DeviceRole).value<QObject *>();
+            DeviceDbusInterface *device = qobject_cast<DeviceDbusInterface *>(deviceObject);
+            if (device == nullptr)
+                continue;
+
             auto indicator = new DeviceIndicator(device);
             QObject::connect(device, &DeviceDbusInterface::destroyed, indicator, &QObject::deleteLater);
 
@@ -104,13 +130,12 @@ int main(int argc, char **argv)
             for (const auto &req : requests) {
                 DeviceDbusInterface *dev = new DeviceDbusInterface(req, menu);
                 auto pairMenu = menu->addMenu(dev->name());
-                pairMenu->addAction(i18n("Pair"), dev, &DeviceDbusInterface::acceptPairing);
-                pairMenu->addAction(i18n("Reject"), dev, &DeviceDbusInterface::rejectPairing);
+                pairMenu->addAction(i18nc("Accept a pairing request", "Pair"), dev, &DeviceDbusInterface::acceptPairing);
+                pairMenu->addAction(i18n("Reject"), dev, &DeviceDbusInterface::cancelPairing);
             }
         }
         // Add quit menu
 #if defined Q_OS_MAC
-
         menu->addAction(i18n("Quit"), []() {
             auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect.daemon"),
                                                           QStringLiteral("/MainApplication"),
@@ -120,21 +145,20 @@ int main(int argc, char **argv)
             qApp->quit();
         });
 #elif defined Q_OS_WIN
-
         menu->addAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Quit"), []() {
             qApp->quit();
         });
 #endif
     };
 
-    QObject::connect(&iface, &DaemonDbusInterface::pairingRequestsChangedProxy, &model, refreshMenu);
+    QObject::connect(&iface, &DaemonDbusInterface::pairingRequestsChanged, &model, refreshMenu);
     QObject::connect(&model, &DevicesModel::rowsInserted, &model, refreshMenu);
     QObject::connect(&model, &DevicesModel::rowsRemoved, &model, refreshMenu);
 
     // Run icon to add icon path (if necessary)
     helper.iconPathHook();
 
-#ifdef QSYSTRAY
+#ifdef Q_OS_WIN
     QSystemTrayIcon systray;
     helper.systrayIconHook(systray);
     systray.setVisible(true);
@@ -174,8 +198,5 @@ int main(int argc, char **argv)
 
     app.setQuitOnLastWindowClosed(false);
 
-    // Finish init
-    helper.postInit();
-
     return app.exec();
 }
