@@ -17,8 +17,7 @@ struct Command {
     QString command;
 };
 
-class KDECONNECTINTERFACES_EXPORT RemoteCommandsModel
-    : public QAbstractListModel
+class KDECONNECTINTERFACES_EXPORT RemoteCommandsModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(QString deviceId READ deviceId WRITE setDeviceId NOTIFY deviceIdChanged)
@@ -27,17 +26,17 @@ public:
     enum ModelRoles {
         KeyRole,
         NameRole,
-        CommandRole
+        CommandRole,
     };
 
-    explicit RemoteCommandsModel(QObject* parent = nullptr);
+    explicit RemoteCommandsModel(QObject *parent = nullptr);
     ~RemoteCommandsModel() override;
 
     QString deviceId() const;
-    void setDeviceId(const QString& deviceId);
+    void setDeviceId(const QString &deviceId);
 
-    QVariant data(const QModelIndex& index, int role) const override;
-    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     QHash<int, QByteArray> roleNames() const override;
 
@@ -46,11 +45,11 @@ private Q_SLOTS:
     void clearCommands();
 
 Q_SIGNALS:
-    void deviceIdChanged(const QString& value);
+    void deviceIdChanged(const QString &value);
     void rowsChanged();
 
 private:
-    RemoteCommandsDbusInterface* m_dbusInterface;
+    RemoteCommandsDbusInterface *m_dbusInterface;
     QVector<Command> m_commandList;
     QString m_deviceId;
 };
