@@ -229,7 +229,13 @@ KIO::WorkerResult KioKdeconnect::stat(const QUrl &url)
         SftpDbusInterface interface(currentDevice);
 
         if (interface.isValid()) {
-            entry.fastInsert(KIO::UDSEntry::UDS_LOCAL_PATH, interface.mountPoint());
+            const QDBusReply<QString> mountPoint = interface.mountPoint();
+
+            if (!mountPoint.isValid()) {
+                return KIO::WorkerResult::fail(KIO::ERR_WORKER_DEFINED, i18n("Failed to get mount point: %1", mountPoint.error().message()));
+            } else {
+                entry.fastInsert(KIO::UDSEntry::UDS_LOCAL_PATH, mountPoint.value());
+            }
 
             if (!interface.isMounted()) {
                 interface.mount();
@@ -249,5 +255,5 @@ KIO::WorkerResult KioKdeconnect::get(const QUrl &url)
     return KIO::WorkerResult::pass();
 }
 
-// needed for JSON file embedding
 #include "kiokdeconnect.moc"
+#include "moc_kiokdeconnect.cpp"
