@@ -18,28 +18,19 @@
 
 K_PLUGIN_CLASS_WITH_JSON(BigscreenPlugin, "kdeconnect_bigscreen.json")
 
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_BIGSCREEN, "kdeconnect.plugin.bigscreen")
-
-BigscreenPlugin::BigscreenPlugin(QObject *parent, const QVariantList &args)
-    : KdeConnectPlugin(parent, args)
-{
-}
-
-BigscreenPlugin::~BigscreenPlugin() = default;
-
-bool BigscreenPlugin::receivePacket(const NetworkPacket &np)
+void BigscreenPlugin::receivePacket(const NetworkPacket &np)
 {
     QString message = np.get<QString>(QStringLiteral("content"));
     /* Emit a signal that will be consumed by Plasma BigScreen:
      * https://invent.kde.org/plasma/plasma-bigscreen/-/blob/master/containments/homescreen/package/contents/ui/indicators/KdeConnect.qml
      */
     Q_EMIT messageReceived(message);
-    return true;
 }
 
 QString BigscreenPlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/bigscreen");
+    return QLatin1String("/modules/kdeconnect/devices/%1/bigscreen").arg(device()->id());
 }
 
 #include "bigscreenplugin.moc"
+#include "moc_bigscreenplugin.cpp"
