@@ -4,31 +4,22 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef CLIPBOARD_CONFIG_H
-#define CLIPBOARD_CONFIG_H
+#pragma once
 
 #include "kcmplugin/kdeconnectpluginkcm.h"
-
-namespace Ui
-{
-class ClipboardConfigUi;
-}
+#include "ui_clipboard_config.h"
 
 class ClipboardConfig : public KdeConnectPluginKcm
 {
     Q_OBJECT
 public:
-    ClipboardConfig(QWidget *parent, const QVariantList &);
-    ~ClipboardConfig() override;
+    ClipboardConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &);
 
-public Q_SLOTS:
     void save() override;
     void load() override;
     void defaults() override;
-    void autoShareChanged();
 
 private:
-    Ui::ClipboardConfigUi *m_ui;
+    void autoShareChanged();
+    Ui::ClipboardConfigUi m_ui;
 };
-
-#endif
