@@ -4,13 +4,13 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef MPRISCONTROLPLUGINWIN_H
-#define MPRISCONTROLPLUGINWIN_H
+#pragma once
 
 #include <core/kdeconnectplugin.h>
 
 #include <variant>
 
+#include <QBuffer>
 #include <QHash>
 #include <vector>
 
@@ -26,36 +26,36 @@ using namespace Windows::ApplicationModel;
 
 #define PACKET_TYPE_MPRIS QStringLiteral("kdeconnect.mpris")
 
-class Q_DECL_EXPORT MprisControlPlugin : public KdeConnectPlugin
+class MprisControlPlugin : public KdeConnectPlugin
 {
     Q_OBJECT
 
 public:
     explicit MprisControlPlugin(QObject *parent, const QVariantList &args);
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
+
+public Q_SLOTS:
+    bool sendAlbumArt(const std::variant<NetworkPacket, QString> &packetOrName, const QSharedPointer<QBuffer> qdata, const QString artUrl);
 
 private:
-    std::optional<GlobalSystemMediaTransportControlsSessionManager> sessionManager;
     QHash<QString, GlobalSystemMediaTransportControlsSession> playerList;
-
+    GlobalSystemMediaTransportControlsSessionManager sessionManager;
     std::vector<GlobalSystemMediaTransportControlsSession::PlaybackInfoChanged_revoker> playbackInfoChangedHandlers;
     std::vector<GlobalSystemMediaTransportControlsSession::MediaPropertiesChanged_revoker> mediaPropertiesChangedHandlers;
     std::vector<GlobalSystemMediaTransportControlsSession::TimelinePropertiesChanged_revoker> timelinePropertiesChangedHandlers;
 
-    std::optional<QString> getPlayerName(GlobalSystemMediaTransportControlsSession const &player);
-    void sendMediaProperties(std::variant<NetworkPacket, QString> const &packetOrName, GlobalSystemMediaTransportControlsSession const &player);
-    void sendPlaybackInfo(std::variant<NetworkPacket, QString> const &packetOrName, GlobalSystemMediaTransportControlsSession const &player);
-    void sendTimelineProperties(std::variant<NetworkPacket, QString> const &packetOrName,
-                                GlobalSystemMediaTransportControlsSession const &player,
+    std::optional<QString> getPlayerName(const GlobalSystemMediaTransportControlsSession &player);
+    void sendMediaProperties(const std::variant<NetworkPacket, QString> &packetOrName, const GlobalSystemMediaTransportControlsSession &player);
+    void sendPlaybackInfo(const std::variant<NetworkPacket, QString> &packetOrName, const GlobalSystemMediaTransportControlsSession &player);
+    void sendTimelineProperties(const std::variant<NetworkPacket, QString> &packetOrName,
+                                const GlobalSystemMediaTransportControlsSession &player,
                                 bool lengthOnly = false);
     void updatePlayerList();
     void sendPlayerList();
-    bool sendAlbumArt(std::variant<NetworkPacket, QString> const &packetOrName, GlobalSystemMediaTransportControlsSession const &player, QString artUrl);
+    void getThumbnail(const std::variant<NetworkPacket, QString> &packetOrName, const GlobalSystemMediaTransportControlsSession &player, const QString artUrl);
+
+    void handleDefaultPlayer(const NetworkPacket &np);
 
     QString randomUrl();
 };
-#endif // MPRISCONTROLPLUGINWIN_H
