@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef MPRISCONTROLPLUGIN_H
-#define MPRISCONTROLPLUGIN_H
+#pragma once
 
 #include <QDBusServiceWatcher>
 #include <QHash>
@@ -52,10 +51,7 @@ class MprisControlPlugin : public KdeConnectPlugin
 public:
     explicit MprisControlPlugin(QObject *parent, const QVariantList &args);
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
 
 private Q_SLOTS:
     void propertiesChanged(const QString &propertyInterface, const QVariantMap &properties);
@@ -73,5 +69,3 @@ private:
     int prevVolume;
     QDBusServiceWatcher *m_watcher;
 };
-
-#endif
