@@ -27,8 +27,6 @@ MprisRemotePlayerMediaPlayer2Player::MprisRemotePlayerMediaPlayer2Player(MprisRe
     connect(m_parent, &MprisRemotePlayer::playingChanged, this, &MprisRemotePlayerMediaPlayer2Player::playingChanged);
 }
 
-MprisRemotePlayerMediaPlayer2Player::~MprisRemotePlayerMediaPlayer2Player() = default;
-
 QString MprisRemotePlayerMediaPlayer2Player::PlaybackStatus() const
 {
     if (m_parent->playing()) {
@@ -55,11 +53,14 @@ QVariantMap MprisRemotePlayerMediaPlayer2Player::Metadata() const
         metadata[QStringLiteral("xesam:title")] = m_parent->title();
     }
     if (!m_parent->artist().isEmpty()) {
-        metadata[QStringLiteral("xesam:artist")] = m_parent->artist();
+        metadata[QStringLiteral("xesam:artist")] = QStringList{m_parent->artist()};
     }
     if (!m_parent->album().isEmpty()) {
         metadata[QStringLiteral("xesam:album")] = m_parent->album();
     }
+    if (!m_parent->localAlbumArtUrl().isEmpty()) {
+        metadata[QStringLiteral("mpris:artUrl")] = m_parent->localAlbumArtUrl().toString();
+    }
     return metadata;
 }
 
@@ -161,17 +162,14 @@ void MprisRemotePlayerMediaPlayer2Player::Seek(qlonglong Offset)
     m_plugin->seek(Offset);
 }
 
-void MprisRemotePlayerMediaPlayer2Player::SetPosition(QDBusObjectPath TrackId, qlonglong Position)
+void MprisRemotePlayerMediaPlayer2Player::SetPosition(QDBusObjectPath /*TrackId*/, qlonglong Position)
 {
-    Q_UNUSED(TrackId)
-
     m_plugin->setPlayer(m_parent->identity());
     m_plugin->setPosition(Position / 1000);
 }
 
-void MprisRemotePlayerMediaPlayer2Player::OpenUri(QString Uri)
+void MprisRemotePlayerMediaPlayer2Player::OpenUri(QString /*Uri*/)
 {
-    Q_UNUSED(Uri)
 }
 
 void MprisRemotePlayerMediaPlayer2Player::controlsChanged()
@@ -248,7 +246,7 @@ void MprisRemotePlayerMediaPlayer2Player::emitPropertiesChanged()
     // Send it over the correct DBus connection
     m_parent->dbus().send(message);
 
-    if (m_positionChanged) {
+    if (m_positionChanged || m_trackInfoChanged) {
         Q_EMIT Seeked(Position());
     }
 
@@ -258,3 +256,5 @@ void MprisRemotePlayerMediaPlayer2Player::emitPropertiesChanged()
     m_positionChanged = false;
     m_volumeChanged = false;
 }
+
+#include "moc_mprisremoteplayermediaplayer2player.cpp"
