@@ -7,8 +7,10 @@
 #include "runcommand_config.h"
 
 #include <QDebug>
+#include <QFileDialog>
 #include <QHBoxLayout>
 #include <QHeaderView>
+#include <QJsonArray>
 #include <QJsonDocument>
 #include <QMenu>
 #include <QPushButton>
@@ -22,18 +24,18 @@
 
 #include <dbushelper.h>
 
-K_PLUGIN_FACTORY(ShareConfigFactory, registerPlugin<RunCommandConfig>();)
+K_PLUGIN_CLASS(RunCommandConfig)
 
-RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
-    : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_runcommand"))
+RunCommandConfig::RunCommandConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KdeConnectPluginKcm(parent, data, args)
 {
     // The qdbus executable name is different on some systems
-    QString qdbusExe = QStringLiteral("qdbus-qt5");
+    QString qdbusExe = QStringLiteral("qdbus-qt6");
     if (QStandardPaths::findExecutable(qdbusExe).isEmpty()) {
         qdbusExe = QStringLiteral("qdbus");
     }
 
-    QMenu *defaultMenu = new QMenu(this);
+    QMenu *defaultMenu = new QMenu(widget());
 
 #ifdef Q_OS_WIN
     addSuggestedCommand(defaultMenu, i18n("Schedule a shutdown"), QStringLiteral("shutdown /s /t 60"));
@@ -45,11 +47,11 @@ RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
     addSuggestedCommand(
         defaultMenu,
         i18n("Say Hello"),
-        QStringLiteral("PowerShell -Command \"Add-Type –AssemblyName System.Speech; (New-Object System.Speech.Synthesis.SpeechSynthesizer).Speak('hello');\""));
+        QStringLiteral("PowerShell -Command Add-Type -AssemblyName System.Speech; (New-Object System.Speech.Synthesis.SpeechSynthesizer).Speak('hello');"));
 #else
-    addSuggestedCommand(defaultMenu, i18n("Shutdown"), QStringLiteral("poweroff"));
-    addSuggestedCommand(defaultMenu, i18n("Reboot"), QStringLiteral("reboot"));
-    addSuggestedCommand(defaultMenu, i18n("Suspend"), QStringLiteral("suspend"));
+    addSuggestedCommand(defaultMenu, i18n("Shutdown"), QStringLiteral("systemctl poweroff"));
+    addSuggestedCommand(defaultMenu, i18n("Reboot"), QStringLiteral("systemctl reboot"));
+    addSuggestedCommand(defaultMenu, i18n("Suspend"), QStringLiteral("systemctl suspend"));
     addSuggestedCommand(
         defaultMenu,
         i18n("Maximum Brightness"),
@@ -65,25 +67,91 @@ RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList &args)
                         QStringLiteral("%0 org.kde.kded5 /modules/plasmavault forceCloseAllVaults").arg(qdbusExe));
 #endif
 
-    QTableView *table = new QTableView(this);
+    QTableView *table = new QTableView(widget());
     table->horizontalHeader()->setStretchLastSection(true);
     table->verticalHeader()->setVisible(false);
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->addWidget(table);
-    QPushButton *button = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Sample commands"), this);
+    QPushButton *button = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Sample commands"), widget());
     button->setMenu(defaultMenu);
-    layout->addWidget(button);
 
-    setLayout(layout);
+    QHBoxLayout *importExportLayout = new QHBoxLayout();
+    QPushButton *exportButton = new QPushButton(i18n("Export"), widget());
+    importExportLayout->addWidget(exportButton);
+    connect(exportButton, &QPushButton::clicked, this, &RunCommandConfig::exportCommands);
+    QPushButton *importButton = new QPushButton(i18n("Import"), widget());
+    importExportLayout->addWidget(importButton);
+    connect(importButton, &QPushButton::clicked, this, &RunCommandConfig::importCommands);
+
+    QVBoxLayout *layout = new QVBoxLayout();
+    layout->addWidget(table);
+    layout->addLayout(importExportLayout);
+    layout->addWidget(button);
+    widget()->setLayout(layout);
 
     m_entriesModel = new QStandardItemModel(this);
     table->setModel(m_entriesModel);
 
-    m_entriesModel->setHorizontalHeaderLabels(QStringList() << i18n("Name") << i18n("Command"));
+    m_entriesModel->setHorizontalHeaderLabels(QStringList{i18n("Name"), i18n("Command")});
 }
 
-RunCommandConfig::~RunCommandConfig()
+void RunCommandConfig::exportCommands()
 {
+    QString filePath = QFileDialog::getSaveFileName(widget(), i18n("Export Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
+    if (filePath.isEmpty())
+        return;
+
+    QFile file(filePath);
+    if (!file.open(QFile::WriteOnly | QFile::Text)) {
+        qWarning() << "Could not write to file:" << filePath;
+        return;
+    }
+
+    QJsonArray jsonArray;
+    for (int i = 0; i < m_entriesModel->rowCount(); i++) {
+        QJsonObject jsonObj;
+        jsonObj[QStringLiteral("name")] = m_entriesModel->index(i, 0).data().toString();
+        jsonObj[QStringLiteral("command")] = m_entriesModel->index(i, 1).data().toString();
+        jsonArray.append(jsonObj);
+    }
+
+    QJsonDocument jsonDocument(jsonArray);
+    file.write(jsonDocument.toJson());
+    file.close();
+}
+
+void RunCommandConfig::importCommands()
+{
+    QString filePath = QFileDialog::getOpenFileName(widget(), i18n("Import Commands"), QDir::homePath(), QStringLiteral("JSON (*.json)"));
+    if (filePath.isEmpty())
+        return;
+
+    QFile file(filePath);
+    if (!file.open(QFile::ReadOnly | QFile::Text)) {
+        qWarning() << "Could not read file:" << filePath;
+        return;
+    }
+
+    QByteArray jsonData = file.readAll();
+    file.close();
+
+    QJsonDocument jsonDoc = QJsonDocument::fromJson(jsonData);
+    if (jsonDoc.isNull() || !jsonDoc.isArray()) {
+        qWarning() << "Invalid JSON format.";
+        return;
+    }
+
+    // Clear the current command list
+    m_entriesModel->removeRows(0, m_entriesModel->rowCount());
+
+    // Populate the model with the imported commands
+    QJsonArray jsonArray = jsonDoc.array();
+    for (const QJsonValue &jsonValue : jsonArray) {
+        QJsonObject jsonObj = jsonValue.toObject();
+        QString name = jsonObj.value(QStringLiteral("name")).toString();
+        QString command = jsonObj.value(QStringLiteral("command")).toString();
+        insertRow(m_entriesModel->rowCount(), name, command);
+    }
+
+    markAsChanged();
 }
 
 void RunCommandConfig::addSuggestedCommand(QMenu *menu, const QString &name, const QString &command)
@@ -91,7 +159,7 @@ void RunCommandConfig::addSuggestedCommand(QMenu *menu, const QString &name, con
     auto action = new QAction(name);
     connect(action, &QAction::triggered, action, [this, name, command]() {
         insertRow(0, name, command);
-        Q_EMIT changed(true);
+        markAsChanged();
     });
     menu->addAction(action);
 }
@@ -101,7 +169,7 @@ void RunCommandConfig::defaults()
     KCModule::defaults();
     m_entriesModel->removeRows(0, m_entriesModel->rowCount());
 
-    Q_EMIT changed(true);
+    markAsChanged();
 }
 
 void RunCommandConfig::load()
@@ -129,12 +197,11 @@ void RunCommandConfig::load()
 
     insertEmptyRow();
     connect(m_entriesModel, &QAbstractItemModel::dataChanged, this, &RunCommandConfig::onDataChanged);
-
-    Q_EMIT changed(false);
 }
 
 void RunCommandConfig::save()
 {
+    KCModule::save();
     QJsonObject jsonConfig;
     for (int i = 0; i < m_entriesModel->rowCount(); i++) {
         QString key = m_entriesModel->item(i, 0)->data().toString();
@@ -146,7 +213,7 @@ void RunCommandConfig::save()
         }
 
         if (key.isEmpty()) {
-            key = QUuid::createUuid().toString();
+            key = QUuid::createUuid().toString(QUuid::WithoutBraces);
             DBusHelper::filterNonExportableCharacters(key);
         }
         QJsonObject entry;
@@ -157,10 +224,6 @@ void RunCommandConfig::save()
     QJsonDocument document;
     document.setObject(jsonConfig);
     config()->set(QStringLiteral("commands"), document.toJson(QJsonDocument::Compact));
-
-    KCModule::save();
-
-    Q_EMIT changed(false);
 }
 
 void RunCommandConfig::insertEmptyRow()
@@ -178,14 +241,14 @@ void RunCommandConfig::insertRow(int i, const QString &name, const QString &comm
     m_entriesModel->insertRow(i, QList<QStandardItem *>() << newName << newCommand);
 }
 
-void RunCommandConfig::onDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
+void RunCommandConfig::onDataChanged(const QModelIndex & /*topLeft*/, const QModelIndex &bottomRight)
 {
-    Q_EMIT changed(true);
-    Q_UNUSED(topLeft);
+    markAsChanged();
     if (bottomRight.row() == m_entriesModel->rowCount() - 1) {
         // TODO check both entries are still empty
         insertEmptyRow();
     }
 }
 
+#include "moc_runcommand_config.cpp"
 #include "runcommand_config.moc"
