@@ -24,8 +24,6 @@ Mounter::Mounter(SftpPlugin *sftp)
     , m_mountPoint(sftp->mountPoint())
     , m_started(false)
 {
-    connect(m_sftp, &SftpPlugin::packetReceived, this, &Mounter::onPackageReceived);
-
     connect(&m_connectTimer, &QTimer::timeout, this, &Mounter::onMountTimeout);
 
     connect(this, &Mounter::mounted, &m_connectTimer, &QTimer::stop);
@@ -58,7 +56,7 @@ bool Mounter::wait()
     return loop.exec();
 }
 
-void Mounter::onPackageReceived(const NetworkPacket &np)
+void Mounter::onPacketReceived(const NetworkPacket &np)
 {
     if (np.get<bool>(QStringLiteral("stop"), false)) {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "SFTP server stopped";
@@ -92,7 +90,7 @@ void Mounter::onPackageReceived(const NetworkPacket &np)
 
     connect(m_proc, &QProcess::started, this, &Mounter::onStarted);
     connect(m_proc, &QProcess::errorOccurred, this, &Mounter::onError);
-    connect(m_proc, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &Mounter::onFinished);
+    connect(m_proc, &QProcess::finished, this, &Mounter::onFinished);
 
     QDir().mkpath(m_mountPoint);
 
@@ -115,22 +113,21 @@ void Mounter::onPackageReceived(const NetworkPacket &np)
         ip.append(QLatin1Char(']'));
     }
 
+    // clang-format off
     const QStringList arguments =
-        QStringList() << QStringLiteral("%1@%2:%3")
-                             .arg(np.get<QString>(QStringLiteral("user")),
-                                  ip,
-                                  path)
+        QStringList() << QStringLiteral("%1@%2:%3").arg(np.get<QString>(QStringLiteral("user")), ip, path)
                       << m_mountPoint << QStringLiteral("-p") << np.get<QString>(QStringLiteral("port"))
                       << QStringLiteral("-s") // This fixes a bug where file chunks are sent out of order and get corrupted on reception
                       << QStringLiteral("-f") << QStringLiteral("-F") << QStringLiteral("/dev/null") // Do not use ~/.ssh/config
-                      << QStringLiteral("-o") << QStringLiteral("IdentityFile=") + KdeConnectConfig::instance().privateKeyPath() << QStringLiteral("-o")
-                      << QStringLiteral("StrictHostKeyChecking=no") // Do not ask for confirmation because it is not a known host
+                      << QStringLiteral("-o") << QStringLiteral("IdentityFile=") + KdeConnectConfig::instance().privateKeyPath()
+                      << QStringLiteral("-o") << QStringLiteral("StrictHostKeyChecking=no") // Do not ask for confirmation because it is not a known host
                       << QStringLiteral("-o") << QStringLiteral("UserKnownHostsFile=/dev/null") // Prevent storing as a known host
-                      << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=+ssh-dss\\,ssh-rsa") // https://bugs.kde.org/show_bug.cgi?id=351725
-                      << QStringLiteral("-o") << QStringLiteral("PubkeyAcceptedKeyTypes=+ssh-rsa") // https://bugs.kde.org/show_bug.cgi?id=443155
-                      << QStringLiteral("-o") << QStringLiteral("uid=") + QString::number(getuid()) << QStringLiteral("-o")
-                      << QStringLiteral("gid=") + QString::number(getgid()) << QStringLiteral("-o") << QStringLiteral("reconnect") << QStringLiteral("-o")
-                      << QStringLiteral("ServerAliveInterval=30") << QStringLiteral("-o") << QStringLiteral("password_stdin");
+                      << QStringLiteral("-o") << QStringLiteral("uid=") + QString::number(getuid())
+                      << QStringLiteral("-o") << QStringLiteral("gid=") + QString::number(getgid())
+                      << QStringLiteral("-o") << QStringLiteral("reconnect")
+                      << QStringLiteral("-o") << QStringLiteral("ServerAliveInterval=30")
+                      << QStringLiteral("-o") << QStringLiteral("password_stdin");
+    // clang-format on
 
     m_proc->setProgram(program, arguments);
 
@@ -217,7 +214,7 @@ void Mounter::unmount(bool finished)
 
             auto proc = m_proc;
             m_proc = nullptr;
-            connect(proc, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), [proc]() {
+            connect(proc, &QProcess::finished, [proc]() {
                 qCDebug(KDECONNECT_PLUGIN_SFTP) << "Free" << proc;
                 proc->deleteLater();
             });
@@ -227,11 +224,13 @@ void Mounter::unmount(bool finished)
 
             // Free mount point (won't always succeed if the path is in use)
 #if defined(HAVE_FUSERMOUNT)
-        KProcess::execute(QStringList() << QStringLiteral("fusermount") << QStringLiteral("-u") << m_mountPoint, 10000);
+        KProcess::execute(QStringList{QStringLiteral("fusermount"), QStringLiteral("-u"), m_mountPoint}, 10000);
 #else
-        KProcess::execute(QStringList() << QStringLiteral("umount") << m_mountPoint, 10000);
+        KProcess::execute(QStringList{QStringLiteral("umount"), m_mountPoint}, 10000);
 #endif
         m_proc = nullptr;
     }
     m_started = false;
 }
+
+#include "moc_mounter.cpp"
