@@ -14,7 +14,7 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 
-K_PLUGIN_FACTORY_WITH_JSON(KdeConnectPluginFactory, "kdeconnect_systemvolume.json", registerPlugin<SystemvolumePlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SystemvolumePlugin, "kdeconnect_systemvolume.json")
 
 class MacOSCoreAudioDevice
 {
@@ -219,7 +219,7 @@ SystemvolumePlugin::~SystemvolumePlugin()
     AudioObjectRemovePropertyListener(kAudioObjectSystemObject, &kAudioDefaultOutputDevicePropertyAddress, &onDefaultChanged, (void *)this);
 }
 
-bool SystemvolumePlugin::receivePacket(const NetworkPacket &np)
+void SystemvolumePlugin::receivePacket(const NetworkPacket &np)
 {
     if (np.has(QStringLiteral("requestSinks"))) {
         sendSinkList();
@@ -238,8 +238,6 @@ bool SystemvolumePlugin::receivePacket(const NetworkPacket &np)
             }
         }
     }
-
-    return true;
 }
 
 void SystemvolumePlugin::sendSinkList()
@@ -275,7 +273,8 @@ void SystemvolumePlugin::sendSinkList()
         // Add data source change listerner
         AudioObjectAddPropertyListener(deviceId, &kAudioMasterDataSourcePropertyAddress, &onOutputSourceChanged, (void *)this);
 
-        QJsonObject sinkObject{{QStringLiteral("name"), QStringLiteral("default-") + QString::number(deviceId)},
+        QString name = QStringLiteral("default-") + QString::number(deviceId);
+        QJsonObject sinkObject{{QStringLiteral("name"), name},
                                {QStringLiteral("muted"), audioDevice->isMuted()},
                                {QStringLiteral("description"), audioDevice->m_description},
                                {QStringLiteral("volume"), audioDevice->volume() * 100},
@@ -463,4 +462,5 @@ void MacOSCoreAudioDevice::updateType()
     }
 }
 
+#include "moc_systemvolumeplugin-macos.cpp"
 #include "systemvolumeplugin-macos.moc"
