@@ -17,11 +17,6 @@
 
 K_PLUGIN_CLASS_WITH_JSON(TelephonyPlugin, "kdeconnect_telephony.json")
 
-TelephonyPlugin::TelephonyPlugin(QObject *parent, const QVariantList &args)
-    : KdeConnectPlugin(parent, args)
-{
-}
-
 void TelephonyPlugin::createNotification(const NetworkPacket &np)
 {
     const QString event = np.get<QString>(QStringLiteral("event"));
@@ -66,30 +61,27 @@ void TelephonyPlugin::createNotification(const NetworkPacket &np)
     m_currentCallNotification->setText(content);
 
     if (event == QLatin1String("ringing")) {
-        m_currentCallNotification->setActions(QStringList(i18n("Mute Call")));
-        connect(m_currentCallNotification, &KNotification::action1Activated, this, &TelephonyPlugin::sendMutePacket);
+        m_currentCallNotification->clearActions();
+        KNotificationAction *muteAction = m_currentCallNotification->addAction(i18n("Mute Call"));
+        connect(muteAction, &KNotificationAction::activated, this, &TelephonyPlugin::sendMutePacket);
     }
 
     m_currentCallNotification->sendEvent();
 }
 
-bool TelephonyPlugin::receivePacket(const NetworkPacket &np)
+void TelephonyPlugin::receivePacket(const NetworkPacket &np)
 {
     if (np.get<bool>(QStringLiteral("isCancel"))) {
         if (m_currentCallNotification) {
             m_currentCallNotification->close();
         }
-        return true;
+        return;
     }
 
     // ignore old style sms packet
-    if (np.get<QString>(QStringLiteral("event")) == QLatin1String("sms")) {
-        return false;
+    if (np.get<QString>(QStringLiteral("event")) != QLatin1String("sms")) {
+        createNotification(np);
     }
-
-    createNotification(np);
-
-    return true;
 }
 
 void TelephonyPlugin::sendMutePacket()
@@ -100,7 +92,8 @@ void TelephonyPlugin::sendMutePacket()
 
 QString TelephonyPlugin::dbusPath() const
 {
-    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/telephony");
+    return QLatin1String("/modules/kdeconnect/devices/%1/telepony").arg(device()->id());
 }
 
+#include "moc_telephonyplugin.cpp"
 #include "telephonyplugin.moc"
