@@ -11,12 +11,15 @@
 #include <QDBusMessage>
 #include <QDialog>
 #include <QFileDialog>
+#include <QIcon>
 #include <QMessageBox>
+#include <QQuickStyle>
 #include <QTextStream>
 #include <QUrl>
 
 #include <KAboutData>
 #include <KColorSchemeManager>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KUrlRequester>
@@ -36,8 +39,6 @@
 
 int main(int argc, char **argv)
 {
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
     const QString description = i18n("KDE Connect URL handler");
@@ -50,13 +51,30 @@ int main(int argc, char **argv)
     about.addAuthor(QStringLiteral("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"));
     about.setProgramLogo(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
     KAboutData::setApplicationData(about);
-    KDBusService dbusService(KDBusService::Unique);
 
 #ifdef Q_OS_WIN
-    KColorSchemeManager manager;
+    // Ensure we have a suitable color theme set for light/dark mode. KColorSchemeManager implicitly applies
+    // a suitable default theme.
+    KColorSchemeManager::instance();
+    // Force breeze style to ensure coloring works consistently in dark mode. Specifically tab colors have
+    // troubles on windows.
     QApplication::setStyle(QStringLiteral("breeze"));
+    // Force breeze icon theme to ensure we can correctly adapt icons to color changes WRT dark/light mode.
+    // Without this we may end up with hicolor and fail to support icon recoloring.
+    QIcon::setThemeName(QStringLiteral("breeze"));
+#else
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 #endif
 
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
+    KCrash::initialize();
+
+    KDBusService dbusService(KDBusService::Unique);
+
     QUrl urlToShare;
     bool open;
     QString deviceId;
@@ -88,7 +106,18 @@ int main(int argc, char **argv)
     uidialog.devicePicker->setModel(&proxyModel);
 
     if (!deviceId.isEmpty()) {
-        uidialog.devicePicker->setCurrentIndex(model.rowForDevice(deviceId));
+        // This is done on rowsInserted because the model isn't populated yet
+        QObject::connect(&model, &QAbstractItemModel::rowsInserted, &app, [&uidialog, &deviceId, &proxyModel](const QModelIndex &parent, int first) {
+            Q_UNUSED(parent);
+            /**
+             * We want to run this only once, but on startup the data is populated, removed then repopulated (rowsInserted() -> rowsRemoved() ->
+             * rowsInserted()). Thus by running only when there were no devices previously, it ensures that the user's selection doesn't change without them
+             * realising.
+             */
+            if (first == 0) {
+                uidialog.devicePicker->setCurrentIndex(proxyModel.rowForDevice(deviceId));
+            }
+        });
     }
 
     uidialog.openOnPeerCheckBox->setChecked(open);
@@ -163,7 +192,7 @@ int main(int argc, char **argv)
             const QString action = open && url.isLocalFile() ? QStringLiteral("openFile") : QStringLiteral("shareUrl");
 
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                              QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/share"),
+                                                              QLatin1String("/modules/kdeconnect/devices/%1/share").arg(device),
                                                               QStringLiteral("org.kde.kdeconnect.device.share"),
                                                               action);
             msg.setArguments({url.toString()});
